<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>AppItemMenu</name>
    <message>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <source>Pin to Top</source>
        <translation>上部に固定</translation>
    </message>
    <message>
        <source>Move to Top</source>
        <translation>上部に移動</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>お気に入りから削除</translation>
    </message>
    <message>
        <source>Add to favorites</source>
        <translation>お気に入りに追加</translation>
    </message>
    <message>
        <source>Remove from desktop</source>
        <translation>デスクトップから削除</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>デスクトップに追加</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>ドックから削除</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>ドックに固定</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>スタートアップから削除</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>スタートアップへ追加</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation>プロキシを使う</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>ディスプレイスケーリングを無効化</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>アンインストール</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <source>Power</source>
        <translation>電源</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>Full-screen Mode</source>
        <translation>全画面モード</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <source>Install</source>
        <translation>インストール</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>削除</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <source>Frequently Used</source>
        <translation>最近使用したもの</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Window Mode</source>
        <translation>ウィンドウ モード</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Internet</source>
        <translation>インターネット</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>チャット</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>ミュージック</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>ビデオ</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>グラフィックス</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>ゲーム</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>オフィス</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>文書</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>開発</translation>
    </message>
    <message>
        <source>System</source>
        <translation>システム</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>その他</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>%1 をアンインストールしてもよろしいですか？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>確認</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <source>Recently Installed</source>
        <translation>最近インストールされたもの</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <source>All Apps</source>
        <translation>すべてのアプリ</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>検索結果はありません</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <source>Free sorting</source>
        <translation>フリー並び替え</translation>
    </message>
    <message>
        <source>Sort by category</source>
        <translation>カテゴリで並べ替え</translation>
    </message>
    <message>
        <source>Sort by name</source>
        <translation>名前で並べ替え</translation>
    </message>
    <message>
        <source>Sorting Mode</source>
        <translation>並び替えモード</translation>
    </message>
    <message>
        <source>Computer</source>
        <translation>コンピューター</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>ピクチャー</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>ドキュメント</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>デスクトップ</translation>
    </message>
    <message>
        <source>Control Center</source>
        <translation>コントロールセンター</translation>
    </message>
</context>
<context>
    <name>launcheritem</name>
    <message>
        <source>Internet</source>
        <translation>インターネット</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>チャット</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>ミュージック</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>ビデオ</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>グラフィックス</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>ゲーム</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>オフィス</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>文書</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>開発</translation>
    </message>
    <message>
        <source>System</source>
        <translation>システム</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>その他</translation>
    </message>
    <message>
        <source>launchpad</source>
        <translation>ランチャー</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>%1 をアンインストールしてもよろしいですか？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>確認</translation>
    </message>
</context>
</TS>